@@ -24,12 +24,12 @@ from pkg_resources import resource_stream
 from gns3converter.adapters import PORT_TYPES
 from gns3converter.models import MODEL_TRANSFORM
 from gns3converter.node import Node
-from gns3converter.interfaces import INTERFACE_RE
+from gns3converter.interfaces import INTERFACE_RE, VBQ_INT_RE
 from gns3converter.topology import LegacyTopology
 from gns3converter.utils import fix_path
 
 
-class Converter():
+class Converter(object):
     """
     GNS3 Topology Converter Class
 
@@ -48,6 +48,16 @@ class Converter():
         logging.getLogger(__name__)
         logging.debug('Topology file: {}'.format(self._topology))
 
+    @property
+    def topology(self):
+        """
+        Return the topology filename the converter is working on
+
+        :return: topology filename
+        :rtype: str
+        """
+        return self._topology
+
     def read_topology(self):
         """
         Read the ini-style topology file using ConfigObj
@@ -109,6 +119,12 @@ class Converter():
         topo = LegacyTopology(sections, old_top)
 
         for instance in sorted(sections):
+
+            if instance.startswith('vbox') \
+                    and isinstance(old_top[instance]['VBoxDevice'], dict):
+                topo.add_conf_item(instance, 'VBoxDevice')
+                old_top[instance].pop('VBoxDevice')
+
             for item in sorted(old_top[instance]):
                 if isinstance(old_top[instance][item], dict):
                     if item in MODEL_TRANSFORM:
@@ -124,8 +140,7 @@ class Converter():
                     else:
                         # It must be a physical item (topo.devices)
                         topo.add_physical_item(instance, item)
-            topo.hv_id += 1
-        return topo.devices, topo.conf, topo.artwork
+        return topo.topology
 
     @staticmethod
     def get_sections(config):
@@ -138,23 +153,25 @@ class Converter():
         """
         return config.sections
 
-    def generate_nodes(self, devices, hypervisors):
+    def generate_nodes(self, topology):
         """
         Generate a list of nodes for the new topology
 
-        :param list devices: list of devices from :py:meth:`process_topology`
-        :param list hypervisors: list of hypervisors from
-                                 :py:meth:`process_topology`
+        :param dict topology: processed topology from
+                              :py:meth:`process_topology`
         :return: a list of dicts on nodes
         :rtype: list
         """
         nodes = []
 
+        devices = topology['devices']
+        hypervisors = topology['conf']
+
         for device in sorted(devices):
             hv_id = devices[device]['hv_id']
-            if hv_id in hypervisors:
+            try:
                 tmp_node = Node(hypervisors[hv_id], self.port_id)
-            else:
+            except IndexError:
                 tmp_node = Node({}, self.port_id)
             # Start building the structure
             tmp_node.node['properties']['name'] = device
@@ -162,6 +179,7 @@ class Converter():
             tmp_node.node['x'] = devices[device]['x']
             tmp_node.node['y'] = devices[device]['y']
             tmp_node.device_info['type'] = devices[device]['type']
+            tmp_node.device_info['desc'] = devices[device]['desc']
 
             # Node Label
             tmp_node.node['label']['text'] = device
@@ -200,7 +218,7 @@ class Converter():
                     tmp_node.node['properties']['slot0'] = 'Leopard-2FE'
 
                 # Calculate the router links
-                tmp_node.calc_router_links()
+                tmp_node.calc_device_links()
 
             elif tmp_node.device_info['type'] == 'Cloud':
                 try:
@@ -210,7 +228,11 @@ class Converter():
 
             elif tmp_node.device_info['type'] == 'FrameRelaySwitch':
                 tmp_node.process_mappings()
-                pass
+
+            elif tmp_node.device_info['type'] == 'VirtualBoxVM':
+                tmp_node.add_to_virtualbox()
+                tmp_node.add_virtualbox_ports()
+                tmp_node.calc_device_links()
 
             # Get the data we need back from the node instance
             self.links.extend(tmp_node.links)
@@ -229,11 +251,12 @@ class Converter():
         :return: list of links
         :rtype: list
         """
-        links = []
+        new_links = []
 
         for link in self.links:
             # Expand port name if required
-            if INTERFACE_RE.search(link['dest_port']):
+            if INTERFACE_RE.search(link['dest_port'])\
+                    or VBQ_INT_RE.search(link['dest_port']):
                 int_type = link['dest_port'][0]
                 dest_port = link['dest_port'].replace(
                     int_type, PORT_TYPES[int_type.upper()])
@@ -248,28 +271,29 @@ class Converter():
                    (link['source_dev'], link['source_port_name'],
                     dest_details['name'], dest_port)
 
-            links.append({'description': desc,
-                          'destination_node_id': dest_details['id'],
-                          'destination_port_id': dest_details['pid'],
-                          'source_port_id': link['source_port_id'],
-                          'source_node_id': link['source_node_id']})
+            new_links.append({'description': desc,
+                              'destination_node_id': dest_details['id'],
+                              'destination_port_id': dest_details['pid'],
+                              'source_port_id': link['source_port_id'],
+                              'source_node_id': link['source_node_id']})
 
         # Remove duplicate links and add link_id
         link_id = 1
-        for link in links:
+        for link in new_links:
             t_link = str(link['source_node_id']) + ':' + \
                 str(link['source_port_id'])
-            for link2 in links:
+            for link2 in new_links:
                 d_link = str(link2['destination_node_id']) + ':' + \
                     str(link2['destination_port_id'])
                 if t_link == d_link:
-                    links.remove(link2)
+                    new_links.remove(link2)
                     break
             link['id'] = link_id
             link_id += 1
 
             self.add_node_connection(link, nodes)
-        return links
+
+        return new_links
 
     @staticmethod
     def device_id_from_name(device_name, nodes):
@@ -438,6 +462,7 @@ class Converter():
                     tmp_shape[shape_item] = shapes[shape][shape_item]
 
             new_shapes[shapes[shape]['type']].append(tmp_shape)
+
         return new_shapes
 
     @staticmethod
@@ -457,6 +482,7 @@ class Converter():
                 tmp_note[note_item] = notes[note][note_item]
 
             new_notes.append(tmp_note)
+
         return new_notes
 
     def generate_images(self, pixmaps):
@@ -482,4 +508,5 @@ class Converter():
                     tmp_image[img_item] = pixmaps[image][img_item]
 
             new_images.append(tmp_image)
-        return new_images
\ No newline at end of file
+
+        return new_images
